@@ -1,5 +1,4 @@
 from functools import update_wrapper
-#from django.contrib.auth.decorators import _CheckLogin
 
 
 def login_not_required(view_func):
@@ -14,10 +13,7 @@ class PublicView(object):
     Forces a view to be public (no login required).
     """
     def __init__(self, view_func):
-        #if isinstance(view_func, _CheckLogin):
-        #    self.view_func = view_func.view_func
-        #else:
-        #    self.view_func = view_func
+        self.view_func = view_func
         update_wrapper(self, view_func)
 
     def __get__(self, obj, cls=None):
